@@ -18,7 +18,6 @@ public class DatabasePanel extends JTabbedPane {
     JTextField oid = new JTextField(20);
     JTextField name = new JTextField(20);
     JTextField owner = new JTextField(20);
-    JTextArea description = new JTextArea(3, 20);
     JTextField encoding = new JTextField(20);
     JTextField location = new JTextField(20);
     JTextField template = new JTextField(20);
@@ -56,12 +55,6 @@ public class DatabasePanel extends JTabbedPane {
         template.setEditable(false);
         istemplate.setEditable(false);
         allowconn.setEditable(false);
-        description.setEditable(false);
-        description.setBorder(owner.getBorder());
-        description.setBackground(owner.getBackground());
-        description.setLineWrap(true);
-        JScrollPane dpane = new JScrollPane(description);
-        dpane.setPreferredSize(description.getPreferredSize());
         
         JSplitPane panel = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
         panel.setOneTouchExpandable(true);
@@ -74,7 +67,6 @@ public class DatabasePanel extends JTabbedPane {
         general_panel.setLayout(new BoxLayout(general_panel, BoxLayout.Y_AXIS));
         general_panel.add(SUtilities.getHorPanel("Database ID :", oid));
         general_panel.add(SUtilities.getHorPanel("Database Name :", name));
-        general_panel.add(SUtilities.getHorPanel("Description :", dpane));
         general_panel.add(SUtilities.getHorPanel("Is Template :", istemplate));
         general_panel.add(SUtilities.getHorPanel("Allow Connections :", allowconn));
         general_panel.add(SUtilities.getHorPanel("Encoding :", encoding));
@@ -96,7 +88,6 @@ public class DatabasePanel extends JTabbedPane {
         encoding.setText(database_object.getEncoding());
         location.setText(database_object.getLocation());
         template.setText(database_object.getTemplate());
-        description.setText(database_object.getDescription());
         
         repaint();
     }
