@@ -17,7 +17,6 @@ public class GroupPanel extends JTabbedPane {
     
     JTextField oid = new JTextField(20);
     JTextField name = new JTextField(20);
-    JTextArea description = new JTextArea(3, 20);
     
     UsersPanel user_panel = new UsersPanel();
 
@@ -60,12 +59,6 @@ public class GroupPanel extends JTabbedPane {
     private void insertDefaultTab() {
         oid.setEditable(false);
         name.setEditable(false);
-        description.setEditable(false);
-        description.setBorder(oid.getBorder());
-        description.setBackground(oid.getBackground());
-        description.setLineWrap(true);
-        JScrollPane dpane = new JScrollPane(description);
-        dpane.setPreferredSize(description.getPreferredSize());
         
         JSplitPane panel = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
         panel.setOneTouchExpandable(true);
@@ -78,7 +71,6 @@ public class GroupPanel extends JTabbedPane {
         general_panel.setLayout(new BoxLayout(general_panel, BoxLayout.Y_AXIS));
         general_panel.add(SUtilities.getHorPanel("Group ID :", oid));
         general_panel.add(SUtilities.getHorPanel("Group Name :", name));
-        general_panel.add(SUtilities.getHorPanel("Description :",dpane));
         
         panel.setTopComponent(SUtilities.centerComponent(general_panel));
         addTab("General", panel);
@@ -88,7 +80,6 @@ public class GroupPanel extends JTabbedPane {
         oid.setText(String.valueOf(group_object.getOID()));
         name.setText(group_object.getName());
         sql.setText(group_object.getInsertSQL());
-        description.setText(group_object.getDescription());
         repaint();
     }
 }
