@@ -21,7 +21,7 @@ public class DataPanelToolbar extends JToolBar {
     public DataPanelToolbar(DataPanel _panel) {
         panel = _panel;
         
-        sort = new JButton(new ImageIcon("images/sort.png"));
+        sort = new JButton(new ImageIcon(getClass().getResource("/images/sort.png")));
         sort.setActionCommand(DataPanelListener.AC_SORT);
         sort.setToolTipText("Sort view");
         sort.addActionListener(panel.getListener());
