@@ -18,7 +18,6 @@ public abstract class DBObject {
     private User creator = null;
     private String name = new String();
     private long oid = -1;
-    private String description = null;
     
     /** Creates a new instance of DBObject
      * @param _owner The owner DBObject for this object.
@@ -45,28 +44,24 @@ public abstract class DBObject {
      */
     public abstract String getUpdateSQL();
     
-    /** Find the object asociated with the OID.
-     * @param _oid OID to search.
-     * @return true if the object was found
-     */
-    public abstract boolean search(long _oid);
-    
     /** Initialize all properties
      */
     protected void initialize(){
         name = new String();
         oid = -1;
-        description = null;
+    }
+    
+    public long getOID(){
+        return oid;
+    }
+    public void setOID(long _oid){
+        oid = _oid;
     }
     
     /** refresh the data from database.
      * if oid>0. Elsewere no action.
      */
-    public void refresh(){
-        if(oid > 0){
-            search(oid);
-        }
-    }
+    public abstract void refresh();
     
     public DBObject getOwner(){
         return owner;
@@ -82,13 +77,6 @@ public abstract class DBObject {
         return creator;
     }
     
-    protected void setOID(long _oid){
-        oid = _oid;
-    }
-    public long getOID(){
-        return oid;
-    }
-    
     public String getName(){
         return name;
     }
@@ -99,30 +87,6 @@ public abstract class DBObject {
             name = new String();
         }
     }
-    public String getDescription(){
-        if(description == null){
-            try{
-                PreparedStatement prep = getConnection().prepareStatement("select * from pg_description where OBJOID = ?");
-                prep.setLong(1, getOID());
-                ResultSet rs = prep.executeQuery();
-                if(rs.next()){
-                    setDescription(rs.getString("DESCRIPTION"));
-                } else {
-                    setDescription(new String());
-                }
-                rs.close();
-                prep.close();
-            } catch (SQLException e){}
-        }
-        return description;
-    }
-    public void setDescription(String _description){
-        if(_description != null){
-            description = _description;
-        } else {
-            description = new String();
-        }
-    }
     
     /** Retrieve the MainConnection for database communications.
      * @return MainConnection to inteact.
