@@ -200,4 +200,12 @@ public class Database extends DBObject {
     public boolean validate(){
         return connection != null;
     }
+    
+    /** refresh the data from database.
+     * if oid>0. Elsewere no action.
+     */
+    public void refresh() {
+        search(getOID());
+    }
+    
 }
