@@ -23,6 +23,7 @@ public class Sequence extends DBObject {
     private boolean cycled = false;
     private boolean called = false;
     private long start = 0;
+    private String description = null;
     
     /** Creates a new instance of Sequence */
     public Sequence(DBObject owner, long oid) {
@@ -133,6 +134,7 @@ public class Sequence extends DBObject {
         cache_value = 0;
         cycled = false;
         called = false;
+        description = null;
     }
     
     // ------ SET AND GET --------
@@ -190,4 +192,45 @@ public class Sequence extends DBObject {
     public void setStart(long _start){
         start = _start;
     }
+    
+    public String getDescription(){
+        if(description == null){
+            try{
+                PreparedStatement prep;
+                
+                if(getConnection().getDatabaseVersion() < 7.2){
+                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                } else {
+                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                    prep.setString(2, getName());
+                }
+                
+                ResultSet rs = prep.executeQuery();
+                if(rs.next()){
+                    setDescription(rs.getString("DESCRIPTION"));
+                } else {
+                    setDescription(new String());
+                }
+                rs.close();
+                prep.close();
+            } catch (SQLException e){}
+        }
+        return description;
+    }
+    public void setDescription(String _description){
+        if(_description != null){
+            description = _description;
+        } else {
+            description = new String();
+        }
+    }
+    /** refresh the data from database.
+     * if oid>0. Elsewere no action.
+     */
+    public void refresh() {
+        search(getOID());
+    }
+    
 }
