@@ -18,6 +18,7 @@ public class Table extends DBObject {
     private long pages_number = 0;
     private Vector columns = null;
     private Vector index = null;
+    private String description = null;
     
     /** Creates a new instance of Table */
     public Table(DBObject owner, long oid) {
@@ -143,6 +144,7 @@ public class Table extends DBObject {
         pages_number = 0;
         columns = null;
         index = null;
+        description = null;
     }
     
     public dataSource getColumnsTable(){
@@ -286,7 +288,6 @@ public class Table extends DBObject {
         return retorno;
     }
 
-    
     private PreparedStatement prepareInsertStatement() throws SQLException{
         StringBuffer sqlComm = new StringBuffer();
         sqlComm.append("INSERT INTO ");
@@ -391,4 +392,45 @@ public class Table extends DBObject {
             e.printStackTrace();
         }
     }
+    
+    public String getDescription(){
+        if(description == null){
+            try{
+                PreparedStatement prep;
+                
+                if(getConnection().getDatabaseVersion() < 7.2){
+                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                } else {
+                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                    prep.setString(2, getName());
+                }
+                
+                ResultSet rs = prep.executeQuery();
+                if(rs.next()){
+                    setDescription(rs.getString("DESCRIPTION"));
+                } else {
+                    setDescription(new String());
+                }
+                rs.close();
+                prep.close();
+            } catch (SQLException e){}
+        }
+        return description;
+    }
+    public void setDescription(String _description){
+        if(_description != null){
+            description = _description;
+        } else {
+            description = new String();
+        }
+    }
+    
+    /** refresh the data from database.
+     * if oid>0. Elsewere no action.
+     */
+    public void refresh() {
+        search(getOID());
+    }
 }
