@@ -19,10 +19,11 @@ public class TableColumn extends DBObject {
     private boolean allow_nulls = false;
     private AttributeType column_type = null;
     private String default_value = new String();
+    private String description = null;
     
-    public TableColumn(DBObject owner, long oid) {
+    public TableColumn(DBObject owner, long attnum) {
         super(owner);
-        search(oid);
+        search(attnum);
     }
     
     /** Retrieve the SQL string that eliminate this object from
@@ -69,31 +70,31 @@ public class TableColumn extends DBObject {
         return new String();
     }
     
-    /** Find the object asociated with the OID.
-     * @param _oid OID to search.
+    /** Find the object asociated with the ATTNUM.
+     * @param _attnum ATTTNUM to search.
      * @return true if the object was found
      */
-    public boolean search(long _oid) {
+    public boolean search(long _attnum) {
         boolean retorno = false;
         try{
             initialize();
             PreparedStatement prep = getConnection().prepareStatement("select "
-            + " pg_attribute.OID, pg_attribute.attnum, pg_attribute.attname, "
+            + " pg_attribute.attnum, pg_attribute.attname, "
             + " case when pg_attribute.attlen > 0 then pg_attribute.attlen "
             + "                 else pg_attribute.atttypmod-4 end as colsize, "
             + " not pg_attribute.attnotnull as allownull, "
             + " adsrc as DEFAULT, pg_attribute.attnelems as vector_elements, "
-            + " pg_attribute.attrelid, pg_attribute.oid, pg_attribute.atttypid "
+            + " pg_attribute.attrelid, pg_attribute.atttypid "
             + " from pg_attribute "
             + "   LEFT JOIN pg_attrdef "
             + "       ON (pg_attribute.attrelid = pg_attrdef.adrelid "
             + "             and pg_attribute.attnum = pg_attrdef.adnum) "
             + " where pg_attribute.attrelid = ? AND pg_attribute.ATTNUM=? ");
             prep.setLong(1, getOwner().getOID());
-            prep.setLong(2, _oid);
+            prep.setLong(2, _attnum);
             ResultSet rs = prep.executeQuery();
             if((rs != null) && (rs.next())){
-                setOID(rs.getLong("OID"));
+                setOID(rs.getInt("attnum"));
                 setName(rs.getString("ATTNAME"));
                 setColumnNumber(rs.getInt("attnum"));
                 setSize(rs.getInt("COLSIZE"));
@@ -115,6 +116,7 @@ public class TableColumn extends DBObject {
         allow_nulls = false;
         column_type = null;
         default_value = new String();
+        description = null;
     }
     
     // ---------SET AND GET-------------
@@ -160,4 +162,45 @@ public class TableColumn extends DBObject {
     private void setColumnType(AttributeType _column_type){
         column_type = _column_type;
     }
+    
+    public String getDescription(){
+        if(description == null){
+            try{
+                PreparedStatement prep;
+                
+                if(getConnection().getDatabaseVersion() < 7.2){
+                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_attribute where attrelid = ? AND ATTNUM=? ");
+                } else {
+                    prep = getConnection().prepareStatement("select col_description(attrelid, ATTNUM) as DESCRIPTION from pg_attribute where attrelid = ? AND ATTNUM=? ");
+                }
+                
+                prep.setLong(1, getOwner().getOID());
+                prep.setLong(2, getColumnNumber());
+                
+                ResultSet rs = prep.executeQuery();
+                if(rs.next()){
+                    setDescription(rs.getString("DESCRIPTION"));
+                } else {
+                    setDescription(new String());
+                }
+                rs.close();
+                prep.close();
+            } catch (SQLException e){}
+        }
+        return description;
+    }
+    public void setDescription(String _description){
+        if(_description != null){
+            description = _description;
+        } else {
+            description = new String();
+        }
+    }
+    
+    /** refresh the data from database.
+     */
+    public void refresh() {
+        search(getColumnNumber());
+    }
+    
 }
