@@ -20,6 +20,7 @@ public class TableIndex extends DBObject {
     private boolean unique = false;
     private boolean primary = false;
     private Vector columns = null;
+    private String description = null;
     
     /** Creates a new instance of TableIndex */
     public TableIndex(DBObject owner, long oid) {
@@ -111,6 +112,7 @@ public class TableIndex extends DBObject {
         unique = false;
         primary = false;
         columns = null;
+        description = null;
     }
     
     
@@ -187,5 +189,45 @@ public class TableIndex extends DBObject {
         primary = _primary;
     }
     
+    public String getDescription(){
+        if(description == null){
+            try{
+                PreparedStatement prep;
+                
+                if(getConnection().getDatabaseVersion() < 7.2){
+                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                } else {
+                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                    prep.setString(2, getName());
+                }
+                
+                ResultSet rs = prep.executeQuery();
+                if(rs.next()){
+                    setDescription(rs.getString("DESCRIPTION"));
+                } else {
+                    setDescription(new String());
+                }
+                rs.close();
+                prep.close();
+            } catch (SQLException e){}
+        }
+        return description;
+    }
+    public void setDescription(String _description){
+        if(_description != null){
+            description = _description;
+        } else {
+            description = new String();
+        }
+    }
+    /** refresh the data from database.
+     * if oid>0. Elsewere no action.
+     */
+    public void refresh() {
+        search(getOID());
+    }
+    
 }
 
