@@ -17,6 +17,7 @@ import java.util.*;
 public class View extends DBObject {
     private String definition = new String();
     private Vector columns = null;
+    private String description = null;
     
     public View(DBObject owner, long oid) {
         super(owner);
@@ -91,6 +92,7 @@ public class View extends DBObject {
         super.initialize();
         definition = new String();
         columns = null;
+        description = null;
     }
     
     public dataSource getColumnsTable(){
@@ -157,5 +159,46 @@ public class View extends DBObject {
         }
         return columns;
     }
+    
+    public String getDescription(){
+        if(description == null){
+            try{
+                PreparedStatement prep;
+                
+                if(getConnection().getDatabaseVersion() < 7.2){
+                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                } else {
+                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where oid=? ");
+                    prep.setLong(1, getOID());
+                    prep.setString(2, getName());
+                }
+                
+                ResultSet rs = prep.executeQuery();
+                if(rs.next()){
+                    setDescription(rs.getString("DESCRIPTION"));
+                } else {
+                    setDescription(new String());
+                }
+                rs.close();
+                prep.close();
+            } catch (SQLException e){}
+        }
+        return description;
+    }
+    public void setDescription(String _description){
+        if(_description != null){
+            description = _description;
+        } else {
+            description = new String();
+        }
+    }
+    /** refresh the data from database.
+     * if oid>0. Elsewere no action.
+     */
+    public void refresh() {
+        search(getOID());
+    }
+    
 }
 
