@@ -21,7 +21,7 @@ public class RootElement extends TreeInfo {
     public RootElement(Database _database) {
         super(null);
         setDatabase(_database);
-        setIcon("./images/objects.gif");
+        setIcon("/images/objects.gif");
     }
 
     public Database getDatabase(){
