@@ -19,7 +19,7 @@ public class TableList extends TreeInfo {
     /** Creates a new instance of TableList */
     public TableList(RootElement  source) {
         super(source);
-        setIcon("./images/table.png");
+        setIcon("/images/table.png");
     }
     
     public long getOID() {
